@@ -2,3 +2,5 @@ pub mod cleaner;
 pub mod filesystem;
 pub mod matcher;
 pub mod walker;
+#[cfg(test)]
+mod test_utils;
\ No newline at end of file
